//@line 36 "/builds/slave/rel-m-rel-lnx-mb-rpk-5/mozilla-release/pt-BR/mobile/mobile-l10n.js"

//@line 38 "/builds/slave/rel-m-rel-lnx-mb-rpk-5/mozilla-release/pt-BR/mobile/mobile-l10n.js"

pref("general.useragent.locale", "pt-BR");
